==> mingw-w64-ngtcp2-1.6.0-2.src.tar.zst: ngtcp2-1.6.0/examples/tls_client_context_picotls.h <==
/*
 * ngtcp2
 *
 * Copyright (c) 2022 ngtcp2 contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef TLS_CLIENT_CONTEXT_PICOTLS_H
#define TLS_CLIENT_CONTEXT_PICOTLS_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif // HAVE_CONFIG_H

#include <picotls.h>
#include <picotls/openssl.h>

class TLSClientContext {
public:
  TLSClientContext();
  ~TLSClientContext();

  int init(const char *private_key_file, const char *cert_file);

  ptls_context_t *get_native_handle();

  void enable_keylog();

private:
  int load_private_key(const char *private_key_file);

  ptls_context_t ctx_;
  ptls_openssl_sign_certificate_t sign_cert_;
};

#endif // TLS_CLIENT_CONTEXT_PICOTLS_H

==> mingw-w64-ngtcp2-1.20.0-1.src.tar.zst: ngtcp2-1.20.0/examples/tls_client_context_picotls.h <==
/*
 * ngtcp2
 *
 * Copyright (c) 2022 ngtcp2 contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef TLS_CLIENT_CONTEXT_PICOTLS_H
#define TLS_CLIENT_CONTEXT_PICOTLS_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif // defined(HAVE_CONFIG_H)

#include <picotls.h>
#include <picotls/openssl.h>

class TLSClientContext {
public:
  TLSClientContext();
  ~TLSClientContext();

  int init(const char *private_key_file, const char *cert_file);

  ptls_context_t *get_native_handle();

  void enable_keylog();

private:
  int load_private_key(const char *private_key_file);

  ptls_context_t ctx_;
  ptls_openssl_sign_certificate_t sign_cert_{};
};

#endif // !defined(TLS_CLIENT_CONTEXT_PICOTLS_H)
